/*
 * The MentalHealth class keeps track of the kobold's mental health.
 */
function MentalHealth() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Sets the lasthit member, if the reason specified is defined.
     * Else, sets the lasthit member to "Unknown".
     * @param {string} hit The last hit.
     */
    function setLastHit(hit) {
        if(hit){
            that.lasthit = hit;
        } else {
            that.lasthit = "Unknown";
        }
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.health = 100;
    this.min = 0;
    this.max = 100;
    this.lasthit = "Unknown";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};
    
    /**
     * Gets the kobold's mental health.
     * @returns {int} The mental health of the kobold.
     */
    this.get = function() {
        return that.health;
    };
    
    /**
     * Sets the kobold's mental health.
     * @param {int} value The new value to set the kobold's mental health.
     */
    this.set = function(value) {
        that.health = value;
    };
    
    /**
     * Increases the kobold's mental health, to a maximum value.
     * @param {int} value How much to increase it.
     * @param {string} reason What happened to cause the change.
     */
    this.increase = function(value, reason) {
        setLastHit(reason);
        var increased = that.health + value;
        if(increased > that.max) {
            increased = that.max;
        }
        that.set(increased);
    };
    
    /**
     * Decreases the kobold's mental health, to a minimum value.
     * @param {int} value How much to decrease it.
     * @param {string} reason What happened to cause the change.
     */
    this.decrease = function(value, reason) {
        setLastHit(reason);
        var decreased = that.health - value;
        if(decreased < that.min) {
            decreased = that.min;
        }
        that.set(decreased);
    };
    

    /**
     * Loads this object from a type-stripped version thereof.
     * @param {MentalHealth-stripped} mentalHealth A MentalHealth object, stripped of private members and all functions.
     */
    this.load = function (mentalHealth) {
        that.health = mentalHealth.health;
        that.min = mentalHealth.min;
        that.max = mentalHealth.max;
        that.lasthit = mentalHealth.lasthit;
    };
}
