/**
 * Mouth section of Enslavement, Night One.
 * @param {CaravanConfinementController} controller The Enslavement, Night One controller.
 */
function CaravanConfinementTeeth(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = CaravanConfinementMouthChoice.TEETH;
    var reqController = ctrl.mouth;
    var subController = ctrl.postMouth;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new CaravanConfinementTightness(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var male = ctrl.misc.baseGender() === GenderEnum.MALE;
        var toReturn = `[p]
                            You don't really want to [i]anger[/i] the man, but you don't feel comfortable with him probing around your mouth either.
                            Your keep your jaw closed, without actively [i]resisting[/i] the human's inspection.
                            He sighs, but he doesn't even [i]attempt[/i] to pry open your muzzle further.
                            Instead, he lowers his head to better gaze into your maw,
                            inspecting what little he can see of your gums, as well as your teeth, internally grading you like a piece of [b]meat[/b].
                        [/p]
                        [p]
                            Finished with his shallow inspection, the man removes his fingers from your muzzle.
                            "[color=brown]I didn't get a good look, but there aren't any apparent diseases.
                            Teeth might need some [b]filing[/b], but that's not [i]our[/i] job.
                            Lizard, next time I want to look in your mouth, you better [b]open up[/b] properly,
                            or I'll [b]hurt you[/b] until you do.
                            Got it?[/color]"
                            You don't bother dignifying his threat with a nod.
                            He knows darn well you heard him.
                        [/p]
                        [p]
                            Your maw graded, the caravan master runs his eyes along the rest your naked frame, examining you from top to bottom.
                            "[color=brown]Some small cuts and bruises.
                            Nothing major.
                            I wouldn't call it [i]pristine[/i] condition, but good enough for sellin'.
                            Attitude could use some adjusting, but some buyers like the ones that still have a little [i]spark[/i] to them.[/color]"
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += subController.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
