/**
 * Controller for the Enslavement, Noon Two scene.
 * @param {string} sceneId The id of the scene.
 */
function SlaveNoonTwoController(sceneId) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var id = sceneId;
    SceneController.call(this, id);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";
    this.nextSceneReady = false;
    this.nextSceneName = "SlaveAfternoonTwo";
    this.nextFolderName = "Enslavement/DayTwo";

    this.sekiSceneReady = false;
    this.sekiSceneName = "SekiWorkshop";
    this.sekiFolderName = "HamletDay2";

    this.farmerSceneReady = false;
    this.farmerSceneName = "FarmerSlave";
    this.farmerFolderName = "Enslavement";

    this.misc = new MiscController(id, "misc");

    this.arrival = new ChangeController(id, "arrival", function () {
        if (global.kobold.history.shared.enslavement.nightOne.knockedOut) {
            global.kobold.status.physical.increase(4, "Troubled sleep");
            global.kobold.status.mental.decrease(8, "Nightmares");
            global.kobold.status.stamina.increase(6, "Troubled sleep");
        } else {
            global.kobold.status.physical.increase(4, "Troubled sleep");
            global.kobold.status.mental.increase(4, "Nightmares");
            global.kobold.status.stamina.increase(6, "Troubled sleep");
        }
    }, function () {
        if (global.kobold.history.shared.enslavement.nightOne.knockedOut) {
            return global.ui.change.buildNotification([
                new Change("Troubled sleep", "Health", +4),
                new Change("Long unconsciousness", "Sanity", -4),
                new Change("Nightmares", "Sanity", -4),
                new Change("Meagre rest", "Stamina", +6)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Troubled sleep", "Health", +4),
                new Change("Slept", "Sanity", +8),
                new Change("Nightmares", "Sanity", -4),
                new Change("Meagre rest", "Stamina", +6)
            ]);
        }
    });

    this.preBlackmail = new ChangeController(id, "preBlackmail", function () {
        if (that.arrival.get() === SlaveNoonTwoArrivalChoice.LOOKOUT) {
            if (global.kobold.history.shared.enslavement.nightOne.knockedOut) {
                global.kobold.status.physical.decrease(7, "Killer headache");
                global.kobold.status.mental.decrease(2, "Woke up early");
            } else {
                global.kobold.status.physical.decrease(5, "Headache");
                global.kobold.status.mental.decrease(2, "Woke up early");
            }
        } else {
            if (global.kobold.history.shared.enslavement.nightOne.knockedOut) {
                global.kobold.status.physical.decrease(5, "Killer headache");
                global.kobold.status.mental.decrease(4, "Crude awakening");
            } else {
                global.kobold.status.physical.decrease(3, "Headache");
                global.kobold.status.mental.decrease(4, "Crude awakening");
            }
        }
    }, function () {
        if (that.arrival.get() === SlaveNoonTwoArrivalChoice.LOOKOUT) {
            if (global.kobold.history.shared.enslavement.nightOne.knockedOut) {
                return global.ui.change.buildNotification([
                    new Change("Stared into the sun", "Health", -2),
                    new Change("Killer headache", "Health", -5),
                    new Change("Waking up early", "Sanity", -2)
                ]);
            } else {
                return global.ui.change.buildNotification([
                    new Change("Stared into the sun", "Health", -2),
                    new Change("Headache", "Health", -3),
                    new Change("Waking up early", "Sanity", -2)
                ]);
            }
        } else {
            if (global.kobold.history.shared.enslavement.nightOne.knockedOut) {
                return global.ui.change.buildNotification([
                    new Change("Killer headache", "Health", -5),
                    new Change("Crude awakening", "Sanity", -4)
                ]);
            } else {
                return global.ui.change.buildNotification([
                    new Change("Headache", "Health", -3),
                    new Change("Crude awakening", "Sanity", -4)
                ]);
            }
        }
    });

    this.offer = new ChangeController(id, "offer", function () {
        if (global.kobold.history.shared.enslavement.nightOne.escapedBindings) {
            global.kobold.status.mental.decrease(2, "Indecent proposal");
        } else {
            global.kobold.status.mental.increase(2, "Indecent proposal");
        }
    }, function () {
        if (global.kobold.history.shared.enslavement.nightOne.escapedBindings) {
            return global.ui.change.buildNotification([
                new Change("Indecent proposal", "Sanity", -1),
                new Change("Considering it", "Sanity", -1)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Hands freed", "Sanity", +4),
                new Change("Indecent proposal", "Sanity", -1),
                new Change("Considering it", "Sanity", -1)
            ]);
        }
    });

    this.blackmail = new ChangeController(id, "blackmail", function () {
        if (global.kobold.history.shared.enslavement.nightOne.escapedBindings) {
            global.kobold.status.mental.decrease(5, "Indecent proposal");
        } else {
            global.kobold.status.mental.decrease(1, "Indecent proposal");
        }
    }, function () {
        if (global.kobold.history.shared.enslavement.nightOne.escapedBindings) {
            return global.ui.change.buildNotification([
                new Change("Grim future", "Sanity", -3),
                new Change("Indecent proposal", "Sanity", -1),
                new Change("Considering it", "Sanity", -1)
            ]);
        } else {
            return global.ui.change.buildNotification([
                new Change("Hands freed", "Sanity", +4),
                new Change("Grim future", "Sanity", -3),
                new Change("Indecent proposal", "Sanity", -1),
                new Change("Considering it", "Sanity", -1)
            ]);
        }
    });

    this.goodNothing = new ChangeController(id, "goodNothing", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+4);
        global.kobold.status.mental.decrease(2, "Inability to decide");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Inability to decide", "Sanity", -2)
        ]);
    });

    this.goodDecline = new ChangeController(id, "goodDecline", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+3);
        global.kobold.status.mental.increase(5, "Stood up for yourself");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Stood up for yourself", "Sanity", +5)
        ]);
    });

    this.goodInsult = new ChangeController(id, "goodInsult", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+2);
        global.kobold.status.mental.increase(4, "Stood up for yourself");
        global.kobold.status.stamina.decrease(2, "Excessive insulting");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Stood up for yourself", "Sanity", +5),
            new Change("Went a little overboard", "Sanity", -1),
            new Change("Excessive insulting", "Stamina", -2)
        ]);
    });

    this.goodAttack = new ChangeController(id, "goodAttack", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+1);
        global.kobold.status.mental.increase(1, "Blind rage");
        global.kobold.status.stamina.decrease(5, "Wild flailing");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Stood up for yourself", "Sanity", +5),
            new Change("Resorted to violence", "Sanity", -2),
            new Change("Blind rage", "Sanity", -2),
            new Change("Wild flailing", "Stamina", -5)
        ]);
    });

    this.goodReluctant = new ChangeController(id, "goodReluctant", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+5);
        global.kobold.status.mental.decrease(7, "Kissing balls");
        global.kobold.status.exertion.increase(5, "Kissing balls");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Humiliation", "Sanity", -10),
            new Change("Amused Fenrir", "Sanity", +3),
            new Change("Kissing balls", "Sexual exhaustion", +5, true)
        ]);
    });

    this.goodEager = new ChangeController(id, "goodEager", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+6);
        global.kobold.status.mental.increase(3, "Pleasing Fenrir");
        global.kobold.status.exertion.increase(10, "Worshipping balls");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Stockholm syndrome", "Sanity", -2),
            new Change("Pleased Fenrir", "Sanity", +5),
            new Change("Eager ball-licking", "Sexual exhaustion", +10, true)
        ]);
    });

    this.badNothing = new ChangeController(id, "badNothing", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+4);
        global.kobold.status.mental.decrease(5, "Impending doom");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Inability to decide", "Sanity", -2),
            new Change("Impending doom", "Sanity", -3)
        ]);
    });

    this.badDecline = new ChangeController(id, "badDecline", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+3);
        global.kobold.status.mental.increase(2, "Impending doom");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Stood up for yourself", "Sanity", +5),
            new Change("Impending doom", "Sanity", -3)
        ]);
    });

    this.badInsult = new ChangeController(id, "badInsult", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+2);
        global.kobold.status.mental.increase(1, "Impending doom");
        global.kobold.status.stamina.decrease(2, "Excessive insulting");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Stood up for yourself", "Sanity", +5),
            new Change("Went a little overboard", "Sanity", -1),
            new Change("Impending doom", "Sanity", -3),
            new Change("Excessive insulting", "Stamina", -2)
        ]);
    });

    this.badAttack = new ChangeController(id, "badAttack", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+1);
        global.kobold.status.mental.decrease(2, "Impending doom");
        global.kobold.status.stamina.decrease(5, "Wild flailing");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Stood up for yourself", "Sanity", +5),
            new Change("Resorted to violence", "Sanity", -2),
            new Change("Blind rage", "Sanity", -2),
            new Change("Impending doom", "Sanity", -3),
            new Change("Wild flailing", "Stamina", -5)
        ]);
    });

    this.badReluctant = new ChangeController(id, "badReluctant", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+5);
        global.kobold.status.mental.decrease(5, "Kissing balls");
        global.kobold.status.exertion.increase(5, "Kissing balls");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Humiliation", "Sanity", -10),
            new Change("Avoided gag", "Sanity", +5),
            new Change("Kissing balls", "Sexual exhaustion", +5, true)
        ]);
    });

    this.badEager = new ChangeController(id, "badEager", function () {
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+6);
        global.kobold.status.mental.increase(8, "Pleasing Fenrir");
        global.kobold.status.exertion.increase(10, "Worshipping balls");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Stockholm syndrome", "Sanity", -2),
            new Change("Pleased Fenrir", "Sanity", +5),
            new Change("Avoided gag", "Sanity", +5),
            new Change("Eager ball-licking", "Sexual exhaustion", +10, true)
        ]);
    });

    this.preGag = new ChoiceController(id, "preGag");

    this.gag = new ChoiceController(id, "gag");

    this.gagRefuse = new ChangeController(id, "gagRefuse", function () {
        global.kobold.inventory.equipment.wear(new UnderwearGag());
        global.kobold.status.physical.decrease(10, "Underwear gag");
        global.kobold.status.mental.decrease(14, "Underwear gag");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Kidney punched", "Health", -7),
            new Change("Unhygienic gag", "Health", -3),
            new Change("Rancid taste", "Sanity", -10),
            new Change("Humiliation", "Sanity", -4)
        ]);
    });

    this.gagOpen = new ChangeController(id, "gagOpen", function () {
        global.kobold.inventory.equipment.wear(new UnderwearGag());
        global.kobold.history.shared.enslavement.noonTwo.alterComplianceRating(+2);
        global.kobold.status.physical.decrease(3, "Underwear gag");
        global.kobold.status.mental.decrease(9, "Underwear gag");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Unhygienic gag", "Health", -3),
            new Change("Kept pride", "Sanity", +5),
            new Change("Rancid taste", "Sanity", -10),
            new Change("Humiliation", "Sanity", -4)
        ]);
    });

    this.preInject = new ChoiceController(id, "preInject");

    this.inject = new ChangeController(id, "inject", function () {
        if (that.misc.dick()) {
            global.kobold.body.growDick(global.kobold.body.dick + 1);
        } else {
            global.kobold.body.growBreasts(global.kobold.body.breasts + 1)
        }
        global.kobold.status.physical.decrease(4, "Pricked by needle");
        global.kobold.status.mental.decrease(12, "Forced transformation");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Pricked by needle", "Health", -4),
            new Change("Forced transformation", "Sanity", -8),
            new Change("Unvented frustration", "Sanity", -4)
        ]);
    });

    this.potion = new ChoiceController(id, "potion");

    this.neither = new ChangeController(id, "neither", function () {
        global.kobold.status.mental.increase(4, "Kind gesture");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Kind gesture", "Sanity", +6)
        ]);
    });

    this.mPlus = new ChangeController(id, "mPlus", function () {
        if (that.misc.dick()) {
            global.kobold.body.growDick(global.kobold.body.dick + 1);
        } else {
            global.kobold.body.growBreasts(global.kobold.body.breasts - 1);
        }
        global.kobold.status.mental.increase(4, "Kind present");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Received present", "Sanity", +6),
            new Change("Transformation", "Sanity", -2)
        ]);
    });

    this.femPlus = new ChangeController(id, "femPlus", function () {
        if (that.misc.dick()) {
            global.kobold.body.growDick(global.kobold.body.dick - 1);
        } else {
            global.kobold.body.growBreasts(global.kobold.body.breasts + 1);
        }
        global.kobold.status.mental.increase(4, "Kind present");
    }, function () {
        return global.ui.change.buildNotification([
            new Change("Received present", "Sanity", +6),
            new Change("Transformation", "Sanity", -2)
        ]);
    });

    this.preOutside = new ChangeController(id, "preOutside");

    this.outside = new ChangeController(id, "outside", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.batheBad = new ChangeController(id, "batheBad", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.batheGood = new ChangeController(id, "batheGood", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.drinkBad = new ChangeController(id, "drinkBad", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.drinkGood = new ChangeController(id, "drinkGood", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.refuseBad = new ChangeController(id, "refuseBad", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.refuseGood = new ChangeController(id, "refuseGood", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.preStage = new ChoiceController(id, "preStage");

    this.stage = new ChangeController(id, "stage", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.pose = new ChangeController(id, "pose", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.refuse = new ChangeController(id, "refuse", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.smile = new ChangeController(id, "smile", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.preResult = new ChoiceController(id, "preResult");

    this.result = new ChangeController(id, "result", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.nobody = new ChangeController(id, "nobody", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.seki = new ChangeController(id, "seki", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.farmer = new ChangeController(id, "farmer", function () {

    }, function () {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.outsideComplianceStorage = new ChoiceController(id, "outsideComplianceStorage");
    this.resultComplianceStorage = new ChoiceController(id, "resultComplianceStorage");
    this.resultBodyMisc = new MiscController(id, "resultBody");

    this.fragments = {};
    this.fragments.results = new SlaveNoonTwoResults(this);
    this.fragments.stage = new SlaveNoonTwoStage(this);
    this.fragments.outside = new SlaveNoonTwoOutside(this);
    this.fragments.gagged = new SlaveNoonTwoBadGag(this);
    this.fragments.notGagged = new SlaveNoonTwoGoodPotion(this);
    this.fragments.proposition = new SlaveNoonTwoProposition(this);

    //this.bgm = new AudioController(id, "res/audio/effects/cave.mp3", 70);

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

}

var SlaveNoonTwoOfferChoice = {
    NOTHING: 1,
    DECLINE: 2,
    INSULT: 3,
    ATTACK: 4,
    RELUCTANT: 5,
    EAGER: 6
};
