/**
 * Builder for the Forest scene.
 * @param {ForestController} controller The controller managing this scene.
 */
function ForestBuilder(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var ctrl = controller;
    var bandit = new ForestBandit(ctrl);
    var home = new ForestHome(ctrl, bandit);
    var woods = new ForestWoods(ctrl, bandit);
    var bridge = new ForestBridge(ctrl);
    var intro = new ForestIntroduction(ctrl, home, bridge, woods);
    var title = `<div class="title fancy">
                    the forest
                </div>`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Progressively builds the contents of the scene.
     * @returns {string} The innards of the scene, as a HTML string.
     */
    this.buildScene = function () {
        var scene = title;
        scene += intro.build();
        scene += bridge.build();
        scene += woods.build();
        scene += home.build();
        return scene;
    };

    /**
     * Registers all the required button listeners.
     */
    this.registerListeners = function () {
        intro.registerListeners();
        bridge.registerListeners();
        woods.registerListeners();
        home.registerListeners();
    };
}
