/**
 * Bargain part of the forest bandit encounter.
 * @param {ForestController} controller The forest controller.
 * @param {ForestBanditReward} reward The reward section.
 */
function ForestBanditBargain(controller, reward) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var payId = "banditBargainPayButton";
    var persuadeId = "banditBargainPersuadeButton";
    var relieveId = "banditBargainRelieveButton";
    var replaceId = "banditBargainReplaceButton";

    var toReward = reward;
    var toRelieve = new ForestBanditRelieve(ctrl);
    var toReplace = new ForestBanditReplace(ctrl);

    var content = ` [p]
                        You decide to bargain with the kobolds.
                        While still bandits, they can't be [i]completely[/i] unreasonable, right?
                        You [b]pray[/b] that they're at least willing to [i]listen[/i] to an agreeable bargain.
                    [/p]
                    [p]
                        Putting on your best faked smile, you take another step forwards, inching a teensy bit closer to the group.
                        Nobody's gouged you yet, which is a good thing. 
                        In fact, they're all still clutching the dragoness' limbs, fearing she'll make a move with you there to distract them.
                        The woman, however, doesn't seem to be willing to risk her life just because a [i]sixth[/i] kobold has appeared on the scene.
                        For all she knows, you're just as [i]wicked[/i] as they are.
                    [/p]`;

    var rock = `    [p]
                        You decide to bargain with the kobolds.
                        While still bandits, they can't be [i]completely[/i] unreasonable, right?
                        You [b]pray[/b] that they're at least willing to [i]listen[/i] to an agreeable bargain, after you knocked one of them out with a rock.
                        Then again, maybe your show of strength will end up working out to your advantage.
                        Only time can tell.
                    [/p]
                    [p]
                        Putting on your best faked smile, you take another step forwards, inching a teensy bit closer to the group.
                        Nobody's gouged you yet, which is a good thing. 
                        In fact, they're all still clutching the dragoness' limbs, fearing she'll make a move now that one of them has been knocked out.
                        With one of her arms freed, she could very well pose a serious threat to the bandits.
                        For now, however, she remains perfectly still, fearful of the blade pressed against her throat.
                    [/p]`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    function buildRock() {
        var toReturn = rock;
        toReturn = global.parser.parse(toReturn);
        return toReturn;
    }

    function buildRegular() {
        var toReturn = content;
        toReturn = global.parser.parse(toReturn);
        return toReturn;
    }

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var src = ctrl.bandit.intervene.getInterveneSource();
        if (src === ForestBanditInterveneSourceEnum.ROCK) {
            return buildRock();
        }
        return  buildRegular();
    }

    /**
     * Builds and returns the pay choice button.
     */
    function buildPayChoice() {
        var disabled = ctrl.bandit.intervene.hasMadeBargainChoice() ? "disabled" : "";
        var isSelected = ctrl.bandit.intervene.getBargainChoice() == ForestBanditBargainChoice.PAY;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${payId}" ${disabled}>Pay them</button>`;

        var tooltip = `Use your bundle of hard-earned gold to persuade the gang to leave the dragoness alone.`;
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 175px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the relieve choice button.
     */
    function buildRelieveChoice() {
        var disabled = ctrl.bandit.intervene.hasMadeBargainChoice() ? "disabled" : "";
        var isSelected = ctrl.bandit.intervene.getBargainChoice() == ForestBanditBargainChoice.RELIEVE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${relieveId}" ${disabled}>Get them off</button>`;

        var tooltip = `Offer an extra mouth and a pair of hands for them to relieve themselves with.
                       The fewer bandits the dragoness has to please, the better, right?`;
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the replace choice button.
     */
    function buildReplaceChoice() {
        var disabled = ctrl.bandit.intervene.hasMadeBargainChoice() ? "disabled" : "";
        var isSelected = ctrl.bandit.intervene.getBargainChoice() == ForestBanditBargainChoice.REPLACE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${replaceId}" ${disabled}>Replace her</button>`;

        var tooltip = `Offer to replace the dragoness completely.
                       Surely someone half her size is bound to be tighter than the oversized woman herself, right?`;
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 205px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You attempt to: </div>`;
        choice += buildPayChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildRelieveChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildReplaceChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all four buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + payId), $("#" + persuadeId), $("#" + relieveId), $("#" + replaceId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the bargain button.
     */
    function registerPayListener() {
        $("#" + payId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.bandit.intervene.makeBargainChoice(ForestBanditBargainChoice.PAY);
            ctrl.bandit.setRewardSource(ForestBanditRewardSourceEnum.PAY);
            loadNextPart(toReward);
        });
    }
    
    /**
     * Adds a listener to the relieve button.
     */
    function registerRelieveListener() {
        $("#" + relieveId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.bandit.intervene.makeBargainChoice(ForestBanditBargainChoice.RELIEVE);
            loadNextPart(toRelieve);
        });
    }
    
    /**
     * Adds a listener to the replace button.
     */
    function registerReplaceListener() {
        $("#" + replaceId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.bandit.intervene.makeBargainChoice(ForestBanditBargainChoice.REPLACE);
            loadNextPart(toReplace);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "banditBargain";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.bandit.intervene.getInterveneChoice() !== ForestBanditInterveneChoiceEnum.BARGAIN) {
            return "";
        }
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        // Build children here.
        part += toRelieve.build();
        part += toReplace.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.bandit.intervene.getInterveneChoice() !== ForestBanditInterveneChoiceEnum.BARGAIN) {
            return;
        }

        // toReward.registerListeners(); // Already registered in arrival.
        toRelieve.registerListeners();
        toReplace.registerListeners();

        if (ctrl.bandit.intervene.hasMadeBargainChoice()) {
            return;
        }

        registerPayListener();
        registerRelieveListener();
        registerReplaceListener();
    };
}

var ForestBanditBargainChoice = {
    PAY: 1,
    RELIEVE: 2,
    REPLACE: 3
};
