/**
 * Bottom section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellKeepClimbingSucceed(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = false;
    var reqController = false;
    var changeController = ctrl.climbUpSucceed;

    var continueId = arguments.callee.name + "ButtonOne"

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.well.escapedClimb = true;
        var toReturn = `[p]
                            You need to keep going.
                            This might be your only way out, and you can't give up just because of a single bad thing happening.
                            Besides, you're already halfway to the top.
                            It'd be a darn [b]shame[/b] to quit now!
                            The way down would be as much of a climb as the way up is.
                            Plus, you're far more motivated by the thought of being [b]freed[/b] from this [i]watery prison[/i]
                            than you are by the premise of being stuck at the bottom [i]again[/i].
                        [/p]
                        [p]
                            It's decided, then.
                            You have to reach the top, no matter how tired or worn out your muscles may be.
                            You raise your arm to a different rock on the same level as the one that broke off a minute ago.
                            Then, the unexpected happens.
                            Like the one before it, this stone, too, breaks from the wall!
                            You are thrown off balance a second time, feeling even more startled than before.
                            You would never have expected two [b]adjacent[/b] rocks to [b]both[/b] be loose!
                        [/p]
                        [p]
                            Time itself seems to slow down as adrenaline floods your system.
                            You can't keep your balance on the shaky rock both your feet are on.
                            You need something new to grab onto, and you need it quick.
                            Looking upwards, you see two stones in the perfect position to hang off of.
                            They're far too high up for you to be able to reach them, though.
                            There's only one answer.
                            Only one thing you can do.
                        [/p]
                        [p]
                            With a soft growl, you [b]leap[/b] upwards, mere [b]moments[/b] before losing your balance completely.
                            Impressing even yourself, you manage to grab onto both of the rocks you were oggling earlier,
                            suspending your entire weight by your arms, while your legs fail to find support.
                            Adrenaline fueling your actions,
                            you amaze yourself further by clambering upwards using nothing but sheer armstrength to hoist your body up onto the next set of grabbable stones,
                            allowing your feet to rest on the rocks you jumped to, and bringing you a whole lot closer to your goal of escaping the well.
                        [/p]
                        [p]
                            You decide to keep climbing, before your sudden burst of strength fades.
                            A few minutes later, you emerge from the well, lifting yourself up and over the stone wall.
                            As adrenaline fades from your system, you collapse on the ground, all four of your limbs completely spent,
                            even your [b]tail[/b] feeling exhausted from the intensive, heart-rattling climb.
                        [/p]
                        [p]
                            [c]
                                [b]
                                    You have escaped the well!
                                [/b]
                            [/c]
                        [/p]
                        [p]
                            You roll onto your back, spread eagle, breathing heavily, staring at the clear sky which you are grateful to see fully once more.
                            That was [b]hard[/b].
                            You didn't even [b]know[/b] you could do some of the things you did.
                            You thought you were going to die.
                            You only [b]barely[/b] made it out alive by the skin of your teeth.
                            In a weird way, however, the rush of excitement you felt when that rock broke off was [b]exhilarating[/b].
                            Defying death was just what you needed to take your mind off of Seki.
                            Maybe you should try that again sometimes.
                            Worst case scenario, you'll meet the old bird in the afterlife.
                        [/p]
                        [p]
                            After a small recovery period, you rise to your spent feet, wisely refraining from leaning against the well.
                            While your limbs are still aching from the extreme strain you put them under, and your heart is still reeling from the intense stress,
                            you feel like you're fit enough to continue on your journey to Varanar.
                            A bit of walking might put both your legs and your mind at ease, and your arms will appreciate a bit of inactivity.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     * @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.varanarSceneName, ctrl.varanarFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        ctrl.bgm.stopLoop();
        global.ui.applyTheme("hamlet_day");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        registerContinueListener();
    };
}
