/**
 * Bottom section of Hamlet, the Well.
 * @param {HamletWellController} controller The Hamlet, Well controller.
 */
function HamletWellScold(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = HamletWellHelpChoice.SCOLD;
    var reqController = ctrl.help;
    var subController = ctrl.preContinue;
    var changeController = ctrl.helpScold;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new HamletWellStuck(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You raise your voice loud enough for them to hear, and you speak up.
                            You tell the boys that they should mind their manners.
                            They can't just go around calling random people dumb!
                            Now, they should go get their parents, and if they're super nice to you,
                            you won't even tell the grown-ups what their children called you.
                        [/p]
                        [p]
                            For a moment, the trio goes silent.
                            While you can't quite tell from where you are [i]swimming[/i],
                            you can imagine them staring at one another in disbelief.
                            Any minute now, they'll apologize, and go fetch some farmers to get you out of here.
                            "[color=red]Hey![/color]" finally comes a response.
                            "[color=red]Since the kobold likes water so much, how about I give it some more?[/color]"
                        [/p]
                        [p]
                            [i]Give you some more?[/i]
                            What does that even mean?
                            Are they going to pour water down the well?
                            "[color=blue]No, Leif, your mom said you weren't allowed to pee in the well![/color]"
                            Wait, what?
                            [i]Pee in the well?[/i]
                            "[color=red]Yeah, but she never said anything about peeing on kobolds![/color]"
                            [i]Oh no.[/i]
                        [/p]
                        [p]
                            From all the way at the top, a thin stream of watery urine sprays down into the well.
                            Due to the remarkable distance between the two of you,
                            the boy mostly ends up doing nothing but splattering the cobblestone wall with pee.
                            A few droplets, manage to make into the water next to you, but you never get hit directly by the troublesome youth.
                        [/p]
                        [p]
                            The stream soon comes to an end, the echoing sound of the tiny flow of splattering piss replaced by your loud, angry hissing,
                            which, in turn, is overshadowed by the trio's building, booming laughter.
                            "[color=red]That enough for you, lizard?![/color]"
                            One of them shouts down at you.
                            You curse your lungs out at them, hurling a barrage of insults and threats their way.
                            "[color=blue]Sounds to me like it wants some more.[/color]" comments one of them.
                            "[color=green]Isn't your uncle a horse? I think I once saw him pee for a minute straight. Let's go get him![/color]"
                        [/p]
                        [p]
                            With that being said, the boys rush off, presumably to find some adult to help them pick on the [b]kobold trapped in the well[/b],
                            You scream for them to come back, to stop playing around and to [b]help you[/b], but your pleas fall on deaf ears, if they were heard at all.
                            You don't really know what to do.
                            If they [i]do[/i] end up getting that [i]horse[/i] they were talking about, the adult might be smart enough to get you out of here.
                            On the other hand, if he's as sadistic as his brother's son is, then you might not want to stick around to wait for his [i]assistance[/i].
                        [/p]
                        [p]
                            Disillusioned about the pure, good-hearted nature of children, you begin to think of another way out of the well.
                            Halfway through conceiving an intricate escape plan concerning your tail and a star-shaped rock of some kind,
                            A loud [i]rumbling[/i] noise echoes throughout the well.
                            Everything begins to shake.
                            Small pebbles and rocks break off the wall and plunge into the water besides you.
                            Earthquake?!
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        if (changeController) {
            part += changeController.change();
        }
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
