/**
 * Buy section of the Workshop scene.
 * @param {SekiWorkshopController} controller The Seki controller.
 */
function SekiWorkshopBuyContinue(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = "buyContinueReduxButton";
    var next = new SekiWorkshopCenter(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p] 
                            With your business concluded, Seki begins to reminisce, as he always does when you come to visit him.
                            "[color=brown]When I was your age, I was out explorin' the world.
                            I fought trolls, I climbed mountains, I even found what I believed to be the fabled well of youth![/color]"
                            A small pause.
                            A smirk forms on Seki's face.
                            He winks at you.
                            "[color=brown]Turns out it was just an ordinary river spring, but you probably could have guessed that by taking a look at me, eh?[/color]"
                        [/p]
                        [p]
                            The old man bursts into laughter, which quickly devolves into a coughing fit.
                            The smile is wiped off his face.
                            Hacking and wheezing, he spits a distinctly red-colored wad of phlegm from his beak onto the ground.
                            You fear for his well-being, the bird visibly hurting, but the moment he catches his breath,
                            he turns towards you, smile plastered across his face once more.
                            You don't know whether or not he's [i]acting[/i] tough.
                        [/p]
                        [p]
                            "[color=brown]Don't worry about me.[/color]"
                            Seki says, as if that's supposed to comfort you.
                            "[color=brown]Just a common cold.
                            Nothin' more.[/color]"
                            You mention that he has the [b]cure[/b] for that.
                            He once made you feel [b]much[/b] better with just a small potion.
                            The owl looks away.
                            All playfulness vanishes from his face, a disconcerting seriousness taking its place.
                            Tears form at the corners of his eyes.
                            He swallows deeply.
                            "[color=brown]It's not the kind of cold that can be cured.[/color]"
                        [/p]
                        [p]
                            The old man pokes a feathery finger underneath his glasses to wipe his eyes, in order to pretend he wasn't crying.
                            He turns towards you once more, a shaky, obviously faked grin on his face.
                            You're still stuck trying to process what he just said.
                            Is Seki going to...die?
                            The owl notices your confusion.
                            He tries to come up with a way to break the grim mood that has fallen upon the conversation, but you can see him visibly struggling for words.
                        [/p]
                        [p]
                            The bird utters a loud, depressing sigh.
                            "[color=brown]Anyway, off you go.[/color]"
                            He speaks, dismissing you with a wave of his hand, before turning around and beginning to walk away at a slow pace.
                            "[color=brown]I'll be in the city for the next few days, but be sure to stop by here sometime before next week, you hear?
                            I want to see my little [b]${ctrl.gender() === GenderEnum.MALE ? "man" : "woman"}[/b] one last time before...[/color]"
                            Stopping mid-sentence, Seki halts his slow walking for a moment.
                            He sadly snorts his nose, before silently disappearing into the darkness,
                            either to tend to his wounds, or to lament in solitude.
                        [/p]
                        [p]
                            Heartbroken, you hang your head and barely refrain from crying as you walk out of the old owl's shop.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.buyContinue.continued();
        var choice = `<div class="choicecontainer">
                        <button class="button inlinechoice ${disabled ? "selected" : ""}" id="${continueId}" ${disabled ? "disabled" : ""}>
                            Continue
                        </button>
                      </div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.buyContinue.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "sekiBuyContinue";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.buy.continued()) {
            return "";
        }
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.buyContinue.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.buy.continued()) {
            return;
        }

        next.registerListeners();

        if (ctrl.buyContinue.continued()) {
            return;
        }

        registerContinueListener();
    };
}
