/**
 * Fight section of the Underground Cave.
 * @param {UndergroundCaveController} controller The Underground Cave controller.
 */
function UndergroundCaveDefence(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var reqChoice = UndergroundCaveFightChoice.DEFENCE;
    var reqController = ctrl.fight;
    var subController = ctrl.preContinue;
    var changeController = ctrl.defence;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new UndergroundCaveDefenceLeave(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        global.kobold.history.shared.well.basiliskFingerDislocated = true;
        var toReturn = `[p]
                            It's [i]only[/i] a feral lizard.
                            If you can dodge its swipes and bites, then surely it will tire out soon, right?
                            All you need to do is [b]not get hit[/b].
                            A basilisk relies on its targets to be [b]petrified[/b], so it shouldn't be able to hit you if you keep moving.
                            At least you hope so.
                            You [b]really[/b] hope so.
                        [/p]
                        [p]
                            While you're still mid-thought, the beast suddenly bursts out into a [b]sprint[/b] towards you.
                            You only [b]barely[/b] manage to pull your left leg back before its teeth sink into your scales, avoiding the lethal bite with a speedy side-step.
                            Angrily, the monster swipes at you with its claws.
                            You take a step backwards to avoid getting hit, ending up at the edge of the pool of liquid you crawled out of.
                            The creature's barrage of attacks [b]keep coming[/b].
                        [/p]
                        [p]
                            Determined to drive you into the water, it follows up with another attempt at biting you.
                            No longer able to retreat, you instead roll to the side,
                            using your innate flexibility and the freedom of motion granted by bipedal movement to stay one step ahead of the rock-clad crocodillian.
                        [/p]
                        [p]
                            Coming out of your roll, you lower into a defensive pose, and hold still for a moment.
                            You and the basilisk are panting,
                            but your water-side duel is not over yet.
                            You both have fight left in you.
                            Although you [b]wish[/b] it would [b]give up[/b] and [b]walk away[/b] already.
                            Surely a skinny kobold like yourself, with barely any meat to pick at, isn't worth a lengthy brawl, right?
                        [/p]
                        [p]
                            Apparently you're wrong.
                            The brief respite is broken.
                            The furious feral lashes at you, turning to the side to swing its rock-hard tail, using it as a weighty whip.
                            Seeing an opening, you tumble not backwards, but [b]forwards[/b],
                            elegantly jumping over the lizard's tail, surprising both it and yourself as you end up directly in front of its drooling maw.
                        [/p]
                        [p]
                            The basilisk is unsure how to react.
                            It could bite you, but it hesitates.
                            You, too, hadn't thought this far ahead.
                            Your mind freezing up, you do the first thing that pops into your brain.
                            You curl your hand into a fist, and bash bash the crocodillian's snout, outright [b]punching[/b] the front of the animal's muzzle.
                        [/p]
                        [p]
                            [big]
                                [color=red][b]CRACK[/b][/color]
                            [/big]
                        [/p]
                        [p]
                            [b]Ow[/b]!!
                            You clutch your hand.
                            It [b]hurts[/b].
                            It feels like you just [b]hit[/b] a [b]rock[/b]!
                            You think something [b]broke[/b], and it wasn't the basilisk's nose.
                        [/p]
                        [p]
                            Still, despite having barely scratched it, the beast recoils as though it's been struck by a mortal wound.
                            You must have frightened it or something.
                            Shown it that you [b]can[/b] and you [b]will[/b] hurt it.
                            Even if you end up hurting yourself [b]even more[/b].
                            You aren't afraid of fighting a pyrrhic battle to the death.
                            A fight in which [b]both[/b] sides lose.
                            And that scares the monster.
                            Or maybe it's just smart enough to know when to run away.
                            It hisses loudly, before turning tail and scampering off back to the hole it came from.
                        [/p]
                        [p]
                            [c]
                                [b]You have scared off the basilisk![/b]
                            [/c]
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = subController.continued() ? "disabled" : "";
        var isSelected = subController.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            subController.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += (changeController && changeController.change()) || "";
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (reqController && ((reqChoice && reqController.get() !== reqChoice) || (!reqChoice && !reqController.continued()))) {
            return;
        }

        next.registerListeners();

        if (subController.continued()) {
            return;
        }

        registerNextListener();
    };
}
