/**
 * Wake up section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeGiveWakeUp(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueHamletId = `toHamletContinueButton`;
    var continueVaranarId = `toVaranarContinueButton`;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You wake up nearly half a day of deep, dreamless sleep later, still tucked in to your hay-bed, relishing in the warmth it provides.
                            As you slowly open your eyes, 
                            you are greeted with the first few rays of morning sunlight shining brightly through the cracks in the walls of your shack.
                            You stay in bed for just a few more minutes.
                        [/p]
                        [p]
                            Finally, you lazily rise from your comfortable position, wiping a few straws of hay off of the top of your head.
                            You yawn loudly, this time not from exhaustion, but out of the satisfaction of a solid night's sleep. 
                            You contently stretch your limbs.
                            You have a feeling today is going to be a good day.
                        [/p]
                        [p]
                            You step out of your small hovel, and are greeted with a gust of fresh, cool morning air, which you breathe in deeply.
                            It reinvigorates you, expells some of the sleepiness from your brain.
                            You rub your eyes as your mind wakes up at its own pace, lagging behind your body as usual.
                        [/p]
                        [p]
                            You've paid off most of your debts.
                            Great.
                            Now you only need to find a way to scrounge up about fifty more coins in a couple of days, and you'll be golden.
                            You doubt you'll be able to gather that money in the forest, though.
                        [/p]
                        [p]
                            You figure it's time to set out,
                            to venture into the city and test your luck there.
                            Maybe you should drop by the small hamlet outside of town first,
                            just to get a better feel for what humans and other species twice your size are like.
                            Whichever route you choose, you hope you'll end up feeling just as [b]good[/b] and [b]fulfilled[/b] as you do now.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.hasContinued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueHamletId}" ${disabled ? "disabled" : ""} style="margin: auto; float: left;">`;
        choice += `To the hamlet &gt;&gt`;
        choice += `</button>`;
        choice += `<button class="button bigbutton continuebutton" id="${continueVaranarId}" ${disabled ? "disabled" : ""} style="margin: auto; float: right;">`;
        choice += `To Varanar &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueHamletId), $("#" + continueVaranarId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }
    
    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     *  @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }
    
    /**
     * Adds a listener to the hamlet button.
     */
    function registerHamletListener() {
        $("#" + continueHamletId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.hamletSceneName, ctrl.hamletFolder);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeGiveWakeUp";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.saved.debt.firstSegmentContinued()) {
            return "";
        }
        global.ui.applyTheme("home_dawn");
        var change = ctrl.saved.debt.acceptWakeChange();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += `<span class="todo">You can only go to the hamlet.</span>`;
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.saved.debt.firstSegmentContinued()) {
            return;
        }
        // REGISTER CHILDREN HERE

        if (ctrl.hasContinued()) {
            return;
        }

        registerHamletListener();
    };
}
