/**
 * Refuse section of the home scene.
 * @param {HomeController} controller The home controller.
 */
function HomeRefuse(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = `refuseContinueButton`;

    var toNext = new HomeRefuseWakeUp(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            So this guy thinks he can [b]bully[/b] you out of [b]your[/b] hard-earned gold just because he's bigger, stronger and [b]heavier[/b] than you are?!
                            No way.
                            You glare up at him with a defiant look on your face as you shake your head no.
                            You aren't going to give him what he wants.
                        [/p]
                        [p]
                            "[color=brown][b]Suit yourself.[/b][/color]"
                            the burly half-kobold replies, looming over you as though he was going to let himself fall forwards and [b]squash[/b] you underneath his weight.
                            Then, out of nowhere, in the flash of an eye, the brute's fist strikes the lower half of your muzzle,
                            with a force strong enough to outright [b]knock[/b] you off your feet.
                        [/p]
                        [p]
                            You scream out in pain as you fall backwards onto the leafy forest floor.
                            The moment you hit the ground, you immediately try to scramble to your feet, or at least to scurry backwards,
                            your fight or flight and self-preservation instincts kicking in.
                            Before you manage to move even an inch, the heavy-set hybrid's foot comes crashing down upon your chest, pinning you against the ground.
                        [/p]
                        [p]
                            Panicking, you struggle and you squirm, yet you fail to escape from the pigbold's clutches.
                            As though he's done this a thousand times before, he ignores your wriggling, 
                            calmly leans down, reaches for the purse now lying atop your chest and harshly [b]tugs[/b] it away from your neck,
                            the flimsy cord keeping it in place snapping with ease.
                        [/p]
                        [p]
                            Having gotten what he was after, the enforcer removes his foot from your chest, and takes a few steps backwards.
                            You instantly hop to your feet, and drop into a combat stance, yet the thug seems uninterested in fighting.
                            Instead, he casually transfers the contents of your gold-pouch into his own pocket.
                        [/p]
                        [p]
                            You slowly slip out of your fighting posture.
                            Your jaw begins to ache as adrenaline fades from your system, 
                            a painful reminder of the sheer [b]strength[/b] of the man before you.
                            The rational part of your brain reasons that even [b]if[/b] he considered you a worthy foe,
                            you'd just end up getting the [b]shit[/b] beaten out of you regardless.
                        [/p]
                        [p]
                            The harsh fact that the half-kobold has [b]won[/b] this [i]not-quite-fight[/i] only truly sinks in 
                            as he tosses the now-empty pouch that used to contain your money in your face.
                            "[color=brown][b]Next time you act uppity, I'll beat you to a pulp.[/b][/color]" the brute warns.
                            You don't doubt his words for even a second.
                            "[color=brown][b]And if this ain't enough to cover your debt, we'll be seeing eachother again real soon.[/b][/color]"
                        [/p]
                        [p]
                            With your coin pocketed and his final threat uttered, the debt collector turns around, and casually strolls away from your humble abode.
                            Disheartened and hurting, you decide not to give chase.
                            Your clutch your jaw, opening and closing your mouth a few times to make sure nothing's [i]broken[/i].
                            It hurts, but you think you'll be fine.
                            Although he only hit you once, he hit you [b]good[/b].
                            And even then, you had the feeling he was still [b]holding back[/b].
                        [/p]
                        [p]
                            You sigh loudly, tying the neck-cord of your once-filled coin pouch back together.
                            You [b]really[/b] wanted to keep at least [b]some[/b] of your money.
                            At least you showed him, and yourself, that you have [b]guts[/b].
                            If you had ${ctrl.gender() === GenderEnum.MALE ? "external" : ""} balls, they'd be as big as a feral horse's.
                            You give yourself a figurative pat on the back for not backing down at first.
                        [/p]
                        [p]
                            After further lamenting your monetary loss, you decide to call it an early night.
                            You step into your small, homely shack, and plop yourself down ontop of the bale of hay that you call your [i]bed[/i].
                            After such a long and tiring day, you easily drift to sleep in a matter of mere minutes.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.saved.debt.firstSegmentContinued();
        var choice = `<div class="choicecontainer">
                        <button class="button inlinechoice ${disabled ? "selected" : ""}" id="${continueId}" ${disabled ? "disabled" : ""}>
                            Continue
                        </button>
                      </div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.saved.debt.firstSegmentContinue();
            loadNextPart(toNext);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "homeRefuse";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.saved.debt.get() !== HomeApproachChoice.REFUSE) {
            return "";
        }
        var change = ctrl.saved.debt.refuseChange(ctrl.gold());
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += change;
        part += buildChoice();
        part += toNext.build();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.saved.debt.get() !== HomeApproachChoice.REFUSE) {
            return;
        }

        toNext.registerListeners();

        if (ctrl.saved.debt.firstSegmentContinued()) {
            return;
        }

        registerContinueListener();
    };
}
